import { gql } from 'mercurius-codegen';

export default gql`
  scalar DateTime

  type User {
    id: ID!
    email: String!
    username: String!
    s3ProfilePicObjectKey: String
    createdAt: DateTime!
    updatedAt: DateTime
    messages: [Message!]
    rooms: [Room!]
    ownedRooms: [Room!]
  }

  type Room {
    id: ID!
    name: String!
    description: String
    isPrivate: Boolean!
    createdAt: DateTime!
    updatedAt: DateTime
    messages: [Message!]
    members: [User!]
    owner: User
  }

  type Message {
    id: ID!
    content: String!
    createdAt: DateTime!
    updatedAt: DateTime
    userId: ID!
    user: User
    roomId: ID!
    room: Room
  }

  type RefreshTokenPayload {
    accessToken: String!
    refreshToken: String!
  }

  type AuthPayload {
    user: User!
    accessToken: String!
    refreshToken: String!
  }

  type PresignedUrl {
    url: String!
    expiresIn: Int!
  }

  type Query {
    me: User
    users: [User!]!
    user(id: ID!): User
    rooms: [Room!]!
    room(id: ID!): Room
    messages(roomId: ID!): [Message!]!
    getProfilePicUploadUrl(fileExtension: String!): PresignedUrl!
    getProfilePicUrl: String
  }

  type Mutation {
    register(
      email: String!
      username: String!
      password: String!
      deviceId: String
    ): AuthPayload!
    login(email: String!, password: String!, deviceId: String): AuthPayload!
    logout(deviceId: String): Boolean!
    refreshToken(deviceId: String): AuthPayload!
    logoutAllDevices: Boolean!
    createRoom(name: String!, description: String, isPrivate: Boolean): Room!
    joinRoom(roomId: ID!): Room!
    leaveRoom(roomId: ID!): Boolean!
    sendMessage(content: String!, roomId: ID!): Message!
    deleteProfilePic: Boolean!
  }

  type Subscription {
    messageAdded(roomId: ID!): Message!
    roomAdded: Room!
    roomUpdated: Room!
  }
`;
